@@ -78,8 +78,8 @@ runTest.word_many <- function(keyphrase,e){
 #  by snapshot strategy.
 runTest.newVar <- function(keyphrase, e){
   # TODO: Eventually make auto-detection of new variables an option.
-  # AUTO_DETECT_NEWVAR is currently hardcoded TRUE. (See utilities.R.)
-  if(!AUTO_DETECT_NEWVAR)e$delta <- safeEval(e$expr, e)
+  # Currently it can be set in customTests.R
+  if(!customTests$AUTO_DETECT_NEWVAR)e$delta <- safeEval(e$expr, e)
   if (length(e$delta)==1){
     e$newVar <- e$delta[[1]]
     e$newVarName <- names(e$delta)[1]
@@ -95,8 +95,8 @@ runTest.newVar <- function(keyphrase, e){
 # keyphrase: correctName=<correct name>
 runTest.correctName <- function(keyphrase, e){
   # TODO: Eventually make auto-detection of new variables an option.
-  # AUTO_DETECT_NEWVAR is currently hardcoded TRUE. (See utilities.R.)
-  if(!AUTO_DETECT_NEWVAR)e$delta <- safeEval(e$expr, e)
+  # Currently it can be set in customTests.R
+  if(!customTests$AUTO_DETECT_NEWVAR)e$delta <- safeEval(e$expr, e)
   correctName <- rightside(keyphrase)
   if ((length(e$delta)==1) && (identical(names(e$delta)[1],correctName))) {
     e$newVar <- e$delta[[1]]
@@ -248,8 +248,8 @@ runTest.matches <- function(keyphrase, e) {
 # keyphrase: creates_var or creates_var=correctName
 runTest.creates_var <- function(keyphrase, e){
   # TODO: Eventually make auto-detection of new variables an option.
-  # AUTO_DETECT_NEWVAR is currently hardcoded TRUE. (See utilities.R.)
-  if(!AUTO_DETECT_NEWVAR)e$delta <- safeEval(e$expr, e)
+  # Currently it can be set in customTests.R
+  if(!customTests$AUTO_DETECT_NEWVAR)e$delta <- safeEval(e$expr, e)
   correctName <- rightside(keyphrase)
   if(is.na(correctName)){
     results <- expectThat(length(e$delta), equals(1), 
