@@ -1,4 +1,9 @@
-#' Install a course from swirl's official list of courses
+#' Install a course from the official course repository
+#' 
+#' We are currently maintaining a central repository of contributed
+#' swirl courses at \url{https://github.com/swirldev/swirl_courses}.
+#' This function provides the easiest method of installing a course
+#' form the repository.
 #' 
 #' @param course_name The name of the course you wish to install.
 #' @export
@@ -6,44 +11,60 @@
 #' @examples
 #' \dontrun{
 #' 
-#' install_from_swirl("Set Theory")
+#' install_from_swirl("R_Programming") # Directory name
+#' 
+#' ### OR ###
+#' 
+#' install_from_swirl("R Programming") # Course name
 #' }
 install_from_swirl <- function(course_name){
   # make pathname from course_name
   course_name <- make_pathname(course_name)
   
   # Construct url to the zip file
-  url <- paste0("http://github.com/swirldev/swirl_courses/zipball/master")
+  url <- "http://github.com/swirldev/swirl_courses/zipball/master"
   
   # Send GET request
   response <- GET(url)
   
   # Construct path to Courses
-  path <- file.path(path.package("swirl"), "Courses", "temp.zip")
+  path <- file.path(system.file("Courses", package = "swirl"), "temp.zip")
   
   # Write the response as a zip
   writeBin(content(response, "raw"), path)
   
   # Find list of files not in top level directory
-  file_names <- unzip(path, list=T)$Name
+  file_names <- unzip(path, list=TRUE)$Name
   
-  # Filter list and extract
+  # Filter list
   unzip_list <- Filter(function(x){grepl(course_name, x)}, file_names)
-  unzip(path, exdir=file.path(path.package("swirl"), "Courses"), files=unzip_list)
+  
+  # Check if course exists
+  if(length(unzip_list) == 0) {
+    stop(paste0("Course '", course_name, "' not found in course repository! ",
+                "Make sure you've got the name exactly right, then try again."))
+  }
+  
+  # Extract
+  unzip(path, exdir=file.path(system.file(package = "swirl"), "Courses"), 
+        files=unzip_list)
   
   # Copy files from unzipped directory into Courses
-  top_dir <- file.path(path.package("swirl"), "Courses", sort(dirname(unzip_list))[1])
-  dirs_to_copy <- list.files(top_dir, full.names=T)
-  file.copy(dirs_to_copy, file.path(path.package("swirl"), "Courses"), recursive=T)
+  top_dir <- file.path(system.file(package = "swirl"), "Courses", 
+                       sort(dirname(unzip_list))[1])
+  dirs_to_copy <- list.files(top_dir, full.names=TRUE)
+  file.copy(dirs_to_copy, file.path(system.file(package = "swirl"), "Courses"),
+            recursive=TRUE)
   
   # Delete unzipped directory
-  unlink(top_dir, recursive=T, force=T)
+  unlink(top_dir, recursive=TRUE, force=TRUE)
   
   # If __MACOSX exists, delete it.
-  unlink(file.path(path.package("swirl"), "Courses", "__MACOSX"), recursive=T, force=T)
+  unlink(file.path(system.file(package = "swirl"), "Courses", "__MACOSX"),
+         recursive=TRUE, force=TRUE)
   
   # Delete temp.zip
-  unlink(path, force=T)
+  unlink(path, force=TRUE)
   
   message("Course installed successfully!")
   
@@ -82,16 +103,17 @@ zip_course <- function(path, dest=NULL){
   # Create directory in which to zip
   zip_dir <- paste0(dest, "/", "swirl_zip_creator_TEMP")
   dir.create(zip_dir)
-  file.copy(path, zip_dir, recursive=T)
+  file.copy(path, zip_dir, recursive=TRUE)
   
   # Change directory to folder to be zipped
   setwd(zip_dir)
   
   # Zip-A-Dee-Doo-Dah
-  zip(paste0(dest, "/", basename(path), ".zip"), list.files(getwd(), recursive=T))
+  zip(paste0(dest, "/", basename(path), ".zip"), 
+      list.files(getwd(), recursive=TRUE))
   
   # Delete temporary directory
-  unlink(zip_dir, recursive=T, force=T)
+  unlink(zip_dir, recursive=TRUE, force=TRUE)
   
   # Pop the old directory
   setwd(curr_dir)
@@ -110,9 +132,10 @@ zip_course <- function(path, dest=NULL){
 #' uninstall_course("Linear Regression")
 #' }
 uninstall_course <- function(course_name){
-  path <- file.path(path.package("swirl"), "Courses", make_pathname(course_name))
+  path <- file.path(system.file(package = "swirl"), "Courses", 
+                    make_pathname(course_name))
   if(file.exists(path)){
-    unlink(path, recursive=T, force=T)
+    unlink(path, recursive=TRUE, force=TRUE)
     message("Course uninstalled successfully!")
   } else {
     stop("Course not found!")
@@ -130,27 +153,32 @@ uninstall_course <- function(course_name){
 install_course_zip <- function(path, multi=FALSE){
   if(multi){
     # Find list of files not in top level directory
-    file_names <- unzip(path, list=T)$Name
+    file_names <- unzip(path, list=TRUE)$Name
     
     # Filter list and extract
     unzip_list <- Filter(function(x){grepl("/.+/", x)}, file_names)
-    unzip(path, exdir=file.path(path.package("swirl"), "Courses"), files=unzip_list)
+    unzip(path, exdir=file.path(system.file(package = "swirl"), "Courses"),
+          files=unzip_list)
     
     # Copy files from unzipped directory into Courses
-    top_dir <- file.path(path.package("swirl"), "Courses", sort(dirname(unzip_list))[1])
-    dirs_to_copy <- list.files(top_dir, full.names=T)
-    file.copy(dirs_to_copy, file.path(path.package("swirl"), "Courses"), recursive=T)
+    top_dir <- file.path(system.file(package = "swirl"), "Courses", 
+                         sort(dirname(unzip_list))[1])
+    dirs_to_copy <- list.files(top_dir, full.names=TRUE)
+    file.copy(dirs_to_copy, file.path(system.file(package = "swirl"),
+                                      "Courses"), recursive=TRUE)
     
     # Delete unzipped directory
-    unlink(top_dir, recursive=T, force=T)
+    unlink(top_dir, recursive=TRUE, force=TRUE)
     
   } else {
     # Unzip file into courses
-    file_list <- unzip(path, exdir=file.path(path.package("swirl"), "Courses"))
+    file_list <- unzip(path, exdir=file.path(system.file(package = "swirl"),
+                                             "Courses"))
   }
   
   # If __MACOSX exists, delete it.
-  unlink(file.path(path.package("swirl"), "Courses", "__MACOSX"), recursive=T, force=T)
+  unlink(file.path(system.file(package = "swirl"), "Courses", "__MACOSX"),
+         recursive=TRUE, force=TRUE)
 
   message("Course installed successfully!")
   invisible()
@@ -168,7 +196,7 @@ install_course_zip <- function(path, multi=FALSE){
 install_course_directory <- function(path){
   # Check for size of directory to prevent copying a huge directory into swirl/Courses
   garbage_result <- tryCatch(
-    {setTimeLimit(elapsed=1); list.files(path, recursive=T)},
+    {setTimeLimit(elapsed=1); list.files(path, recursive=TRUE)},
     finally = {setTimeLimit(elapsed=Inf)}
   )
   
@@ -178,7 +206,8 @@ install_course_directory <- function(path){
   }
   
   # Copy files
-  file.copy(path, file.path(path.package("swirl"), "Courses"), recursive=T)
+  file.copy(path, file.path(system.file(package = "swirl"), "Courses"),
+            recursive=TRUE)
   
   message("Course installed successfully!")
   invisible()
@@ -197,10 +226,12 @@ install_course_directory <- function(path){
 #' install_course_github("bcaffo", "Linear_Regression")
 #' install_course_github("jtleek", "Twitter_Map", "geojson")
 #' }
-install_course_github <- function(github_username, course_name, branch="master", multi=FALSE){
+install_course_github <- function(github_username, course_name, 
+                                  branch="master", multi=FALSE){
   
   # Construct url to the zip file
-  zip_url <- paste0("http://github.com/", github_username, "/", course_name,"/zipball/", branch)
+  zip_url <- paste0("http://github.com/", github_username, "/", 
+                    course_name,"/zipball/", branch)
 
   install_course_url(zip_url, multi=multi)
 }
@@ -234,7 +265,8 @@ install_course_dropbox <- function(url, multi=FALSE){
 #' }
 install_course_google_drive <- function(url, multi=FALSE){
   # Construct url to the zip file
-  zip_url <- sub("file/d/", "uc?export=download&id=", sub("/edit\\?usp=sharing", "", url))
+  zip_url <- sub("file/d/", "uc?export=download&id=", 
+                 sub("/edit\\?usp=sharing", "", url))
   
   install_course_url(zip_url, multi=multi)
 }
@@ -256,7 +288,7 @@ install_course_url <- function(url, multi=FALSE){
   response <- GET(url)
   
   # Construct path to Courses
-  path <- file.path(path.package("swirl"), "Courses", "temp.zip")
+  path <- file.path(system.file(package = "swirl"), "Courses", "temp.zip")
   
   # Write the response as a zip
   writeBin(content(response, "raw"), path)
@@ -267,21 +299,24 @@ install_course_url <- function(url, multi=FALSE){
   # Clean up GitHub directory name
   if(grepl("github.com", url) && !multi){
     # Get paths of every file in zip that will be extracted
-    file_names <- dirname(unzip(path,  list = T)$Name)
+    file_names <- dirname(unzip(path,  list = TRUE)$Name)
     
     # Find subset of those names which is not equal to root, then get the shortest string from that subset
     old_name <- head( sort( file_names[which(file_names != ".")] ) , 1)
     
     # Extract course name
-    course_name <- sub("/zipball", "", str_extract(url, perl("[^/]+/{1}zipball")) )
+    course_name <- sub("/zipball", "", 
+                       str_extract(url, perl("[^/]+/{1}zipball")) )
     
     # Rename unzipped directory
-    file.rename(file.path(path.package("swirl"), "Courses", old_name), 
-                file.path(path.package("swirl"), "Courses", course_name))
+    file.rename(file.path(system.file(package = "swirl"), 
+                          "Courses", old_name), 
+                file.path(system.file(package = "swirl"), 
+                          "Courses", course_name))
   }
   
   # Delete downloaded zip
-  unlink(path, force=T)
+  unlink(path, force=TRUE)
   
   invisible()
 }
