@@ -2,5 +2,5 @@ saveProgress <- function(e)UseMethod("saveProgress")
 
 saveProgress.default <- function(e){
   # save progress
-  saveRDS(e, e$progress)
+  suppressMessages(suppressWarnings(saveRDS(e, e$progress)))
 }
\ No newline at end of file
