@@ -7,6 +7,12 @@ swirl_out <- function(..., skip_before=TRUE, skip_after=FALSE) {
   message(mes)
 }
 
+# Takes a plain English name and turns it into a more proper 
+# file or directory name
+make_pathname <- function(name) {
+  gsub(" ", "_", str_trim(name))
+}
+
 xfer <- function(env1, env2){
   lapply(ls(env1), function(var)getAssign(var, env1, env2))
 }
@@ -53,7 +59,7 @@ mergeLists <- function(sourceList, destList){
 safeEval <- function(expr, e){
   e1 <- cleanEnv(e$snapshot)
   ans <- list()
-  eval(expr,e1)
+  suppressMessages(suppressWarnings(eval(expr,e1)))
   for (x in ls(e1)){
     if(exists(x,globalenv()))
       ans[[x]] <- get(x,globalenv())
@@ -97,6 +103,46 @@ cleanEnv <- function(snapshot){
   return(new.env(parent=pe))
 }
 
-# TODO: Eventually make auto-detection of new variables an option.
-# AUTO_DETECT_NEWVAR is currently hardcoded TRUE.
-AUTO_DETECT_NEWVAR <- TRUE
\ No newline at end of file
+
+# LESSON PACKAGE DEPENDENCY SUPPORT
+
+# Load lesson package dependencies quietly
+loadDependencies <- function(lesson_dir) {
+  depends <- file.path(lesson_dir, "dependson.txt")
+  if(file.exists(depends)) {
+    packages_as_chars <- setdiff(readLines(depends, warn=FALSE), "")
+    # If the dependson file is empty, then proceed with lesson
+    if(length(packages_as_chars) == 0) return(TRUE)
+    swirl_out("Attemping to load lesson dependencies...")
+    for(p in packages_as_chars) {
+      if(suppressPackageStartupMessages(
+        suppressWarnings(
+          suppressMessages(require(p, character.only=TRUE, quietly=TRUE))))) {
+        swirl_out("Package", sQuote(p), "loaded correctly!")
+      } else {
+        swirl_out("This lesson requires the", sQuote(p), 
+                  "package. Would you like me to install it for you now?")
+        yn <- select.list(choices=c("Yes", "No"), graphics=FALSE)
+        if(yn == "Yes") {
+          swirl_out("Trying to install package", sQuote(p), "now...")
+          install.packages(p, quiet=TRUE)
+          if(suppressPackageStartupMessages(
+            suppressWarnings(
+              suppressMessages(require(p, 
+                                       character.only=TRUE, 
+                                       quietly=TRUE))))) {
+            swirl_out("Package", sQuote(p), "loaded correctly!")
+          } else {
+            swirl_out("Could not install package", paste0(sQuote(p), "!"))
+            return(FALSE)
+          }
+        } else {
+          return(FALSE)
+        }
+      }
+    }
+  }
+  # If loop completes, then print a blank line and return TRUE
+  cat("\n")
+  return(TRUE)
+}
\ No newline at end of file
